#!/bin/sh
#
# Copyright(C) 2003-2005 ALWIL Software.  All rights reserved.
#
# the avast! 4.6.3 engine library installer
#

sys_prefix=""
usr_prefix="/usr"
var_prefix="/var"

sysdir="$sys_prefix/etc"
bindir="$usr_prefix/bin"
libdir="$usr_prefix/lib"
docdir="$usr_prefix/share/doc"
mandir="$usr_prefix/share/man"

tempdir="$var_prefix/tmp/avast4"
datadir="$var_prefix/lib/avast4"
moveddir="$var_prefix/lib/avast4/moved"
logdir="$var_prefix/log/avast4"
licdir="$var_prefix/lib/avast4"


# Environment variables
PATH=.:/bin:/usr/bin:/usr/local/bin:/sbin:$PATH
export PATH

##############################
# Subroutines
##############################

platform="Linux"
architecture="i386"
osstyle="other"

# check user (must be root)
check_user()
{
	if [ $(id -u ) -ne 0 ]; then
		echo ""
		echo "This script must be run as root."
		echo " "
		exit 1
	fi
}

# check OS
check_os()
{
	platform=`uname -s`;
	if [ "$platform" != "Linux" ]; then
	    if [ "$platform" != "FreeBSD" ]; then
		echo ""
		echo "Your operating system is not supported by the installer."
		echo " "
		exit 1
	    fi
	fi
	#check os style
	if test -f /etc/init.d/functions
	then
		osstyle="rh"
	elif test -f /etc/rc.status
	then
		osstyle="suse"
	elif test -f /lib/lsb/init-functions
	then
		osstyle="lsb"
	else
		osstyle="other"
	fi
}

# check architecture
check_architecture()
{
	architecture=`uname -m`
	case $architecture in
	  i[3456]86)
	    ;;
	  x86_64)
	    ;;
	  *)
		echo ""
		echo "Your architecture ($architecture) is not supported."
		echo " "
		exit 1
	    ;;
	esac
}

##############################
# Main Section
##############################

libname="libavastengine"
librelease="4"
libcurrent="6"
librevision="6"
libage="0"

#check functions
#check_user
check_os
check_architecture

#default variables
avast4vpsreload="avastvpsreload"
avast4vpsupdate="avastvpsupdate.pl"
avast4vpsupdateconf="avastvpsupdate.conf"
avast4conffile="avastengine.conf"
avast4vpsfile="400.vps"
avast4licfile="License.dat"
if [ $platform = "Linux" ]; then
  avast4libname="$libname-$librelease.so.$libcurrent.$libage.$librevision"
  avast4liblink="$libname-$librelease.so.$libcurrent"
else
  avast4libname="$libname-$librelease.so.$libcurrent"
  avast4liblink="$libname-$librelease.so"
fi
avast4liblink2="$libname.so"

#avast4libdir="/usr/lib"
avast4sharedir="/var/lib/avast4"
surgemaildir="/usr/local/surgemail"

CRONTABTMP="/tmp/roottab.tmp"
instdir="`dirname "$0"`"


progname=$0
version=0.0.5
packagename="libavastengine"
packagevers="4.6.3"


func_usage ()
{
    echo "Usage: $progname [OPTION...]"
    echo "Try '$progname --help' or '$progname -h' for more information."
}

func_help ()
{
    echo "Usage: $progname [OPTION...]"
    echo "$progname -- the avast! engine installer"
    echo ""
    echo "Options:"
    echo "   -p, --prefix          Set installation path"
    echo "   -u, --uninstall       Uninstall previously installed version"
    echo "   -c, --mkconf          Install configuration file for current user"
    echo "   -v, --mkupdateconf    Install VPS updating configuration for current user"
    echo "   -h, --help            Give this help list"
    echo "   -V, --version         Print program version"
    echo ""
    echo "Report bugs to <support@avast.com>."
}

func_version ()
{
    echo "$progname: the avast! engine installer $version"
    echo "Copyright (C) 2005. ALWIL Software. All rights reserved"
}

func_docheck ()
{
    echo "Checking for previous $libname installation"

    check_lib_librarydir=""
    check_man1_vpsreloaddir=""
    check_man1_vpsupdatedir=""
    check_man5_engineconfdir=""
    check_bin_vpsreloaddir=""
    check_bin_vpsupdatedir=""
    check_doc_dir=""
    check_var_avast4datadir=""
    check_var_avast4tempdir=""
    check_var_avast4moveddir=""
    check_var_avast4logdir=""
    check_var_avast4licensedir=""
    check_var_avast4licensefile=""

    #look for the shared library
    tmp_libdir=""
    if [ "$platform" = "Linux" ]; then
       ld_paths=`cat /etc/ld.so.conf`;
    else
       ld_paths=`cat /etc/defaults/rc.conf | grep -w "ldconfig_paths" | sed -e 's/[^\"]*\"\(.*\)\".*/\1/'`;
    fi
    for x in $libdir $ld_paths /usr/local/lib /usr/lib
    do
	#[ -x $x/$avast4liblink ] && {
	#tmp_libdir=$x;
	[ -f $x/$avast4libname ] && {
	check_lib_librarydir=$x;
	break;
	}
    done
    #if [ -f $tmp_libdir/$avast4libname ]; then check_lib_avast4libpath=$tmp_libdir/avast4libname ; fi

    #check for manual pages
    for x in $mandir `echo $MANPATH | sed 's/:/ /g'` /usr/local/share/man /usr/local/man /usr/share/man
    do
	[ -z $check_man1_vpsreloaddir ] && [ -f $x/man1/$avast4vpsreload.1 ] && {
	check_man1_vpsreloaddir=$x/man1;
	}
	[ -z $check_man1_vpsupdatedir ] && [ -f $x/man1/$avast4vpsupdate.1 ] && {
	check_man1_vpsupdatedir=$x/man1;
	}
	[ -z $check_man5_engineconfdir ] && [ -f $x/man5/$avast4conffile.5 ] && {
	check_man5_engineconfdir=$x/man5;
	}
    done

    #check for binary files
    for x in $bindir `echo $PATH | sed 's/:/ /g'`
    do
	[ -z $check_bin_vpsreloaddir ] && [ -f $x/avastvpsreload ] && {
	check_bin_vpsreloaddir=$x;
	}
	[ -z $check_bin_vpsupdatedir ] && [ -f $x/avastvpsupdate.pl ] && {
	check_bin_vpsupdatedir=$x;
	}
    done

    #check for documentation
    for x in $docdir /usr/shared/doc /usr/local/share/doc
    do
	[ -z $check_doc_dir ] && [ -d $x/$packagename-$packagevers ] && {
	check_doc_dir=$x/$packagename-$packagevers;
	}
    done

    conffile_=$sysdir/$avast4conffile
    #look for shared directory
    tmpstr=`cat $conffile_ 2>/dev/null | grep Avast4DataDir | sed 's/.*=//'`
    if [ ! -z $tmpstr ]; then
	check_var_avast4datadir=$tmpstr
    fi
    tmpstr=`cat $conffile_ 2>/dev/null | grep Avast4TempDir | sed 's/.*=//'`
    if [ ! -z $tmpstr ]; then
	check_var_avast4tempdir=$tmpstr
    fi
    tmpstr=`cat $conffile_ 2>/dev/null | grep Avast4MovedDir | sed 's/.*=//'`
    if [ ! -z $tmpstr ]; then
	check_var_avast4moveddir=$tmpstr
    fi
    tmpstr=`cat $conffile_ 2>/dev/null | grep Avast4LogDir | sed 's/.*=//'`
    if [ ! -z $tmpstr ]; then
	check_var_avast4logdir=$tmpstr
    fi
    tmpstr=`cat $conffile_ 2>/dev/null | grep Avast4LicenseDir | sed 's/.*=//'`
    if [ ! -z $tmpstr ]; then
	check_var_avast4licensedir=$tmpstr
    fi
    tmpstr=`cat $conffile_ 2>/dev/null | grep Avast4LicenseFile | sed 's/.*=//'`
    if [ ! -z $tmpstr ]; then
	check_var_avast4licensefile=$tmpstr
    fi
}


  get_agreement() {
    local key
    local res=1
    printf "[ yes / no ] "
    read key

    case $key in
    '') ;;
    'y') ;;
    'Y') ;;
    'yes') ;;
    'Yes') ;;
    'ok') ;;
    *)
        res=0
        ;;
    esac
    return $res;
  }

  get_installagreement() {
    local key
    printf "[ $1 ] "
    read key

    if [ -z $key ];then
	tmpstr=$1
    else
	tmpstr=$key
    fi
  }

func_install ()
{
    ##################
    # Welcome user
    ##################
    echo ""
    echo ""
    echo "Copyright(C) 2003-2005 ALWIL Software.  All rights reserved."
    echo ""
    echo "the avast! engine for $platform will be installed on this"
    echo "machine"
    echo ""
    echo "Technical support is available at:"
    echo "http://www.avast.com/eng/support/technical_support.html"
    echo ""
    echo "Support is available at http://www.asw.cz/support/"
    echo ""
    echo "Default avast installer modified by NetWin for use with surgemail"
    echo "It is recommended to use the default file locations"
    echo "For surgemail specific questions contact surgemail support:"
    echo "      http://netwinsite.com/support.htm"
    echo ""
    echo "To install '$avast4libname' library now, press ENTER."
    echo ""
    echo "To cancel the installation at any time, press Control-C."
    echo ""
    read cont < /dev/tty

    #check for previous library intallation
    func_docheck
    echo ""
    previnstall=0;
    if [ ! -z $check_lib_librarydir ] ; then echo "found installed $check_lib_librarydir/$avast4libname file" ; previnstall=1 ; fi
    if [ ! -z $check_bin_vpsreloaddir ] ; then echo "found installed $check_bin_vpsreloaddir/$avast4vpsreload file" ; previnstall=1 ;fi
    if [ ! -z $check_bin_vpsupdatedir ] ; then echo "found installed $check_bin_vpsupdatedir/$avast4vpsupdate file" ; previnstall=1 ;fi
    if [ ! -z $check_man1_vpsreloaddir ] ; then echo "found installed $check_man1_vpsreloaddir/$avast4vpsreload.1 file" ; previnstall=1 ;fi
    if [ ! -z $check_man1_vpsupdatedir ] ; then echo "found installed $check_man1_vpsupdatedir/$avast4vpsupdate.1 file" ; previnstall=1 ;fi
    if [ ! -z $check_man5_engineconfdir ] ; then echo "found installed $check_man5_engineconfdir/$avast4conffile.5 file" ; previnstall=1 ;fi
    if [ ! -z $check_doc_dir ] ; then echo "found installed $check_doc_dir directory" ; previnstall=1 ;fi

    if [ $previnstall -eq 1 ] ; then
	echo ""
        echo "Do you want to proceed with the installation?"
	get_agreement
        if [ $? -eq 0 ] ; then
	    echo ""
	    echo "To uninstall previously installed files type: $progname --uninstall"
	    echo ""
	    exit 1
        fi
    fi

    #committing installing paths
    echo ""
    echo "Do you want to install this package to the following directories:"
    echo "    configuration to:  $sysdir"
    echo "    binary files to:   $bindir"
    echo "    shared library to: $libdir"
    echo "    manual pages to:   $mandir"
    echo "    documentation to:  $docdir"
    echo ""
    echo "    The following directories will be used by the shared library:"
    echo "        data dir:    $datadir"
    echo "        temp dir:    $tempdir"
    echo "        log dir:     $logdir"
    echo "        moved dir:   $moveddir"
    echo "        license dir: $licdir"
    echo ""

    get_agreement
    if [ $? -eq 0 ] ; then 
      echo ""
      echo "Please use '--prefix' option to set installation path";
      echo ""
      exit 1
    fi

    #check install paths
    oklibpath=0
    if [ "$platform" = "Linux" ]; then
       ld_paths=`cat /etc/ld.so.conf`;
    else
       ld_paths=`cat /etc/defaults/rc.conf | grep -w "ldconfig_paths" | sed -e 's/[^\"]*\"\(.*\)\".*/\1/'`;
    fi
    for x in $ld_paths /usr/local/lib /usr/lib
    do
	[ "$x" = "$usr_prefix/lib" ] && {
	oklibpath=1;
	break;
	}
    done

    okbinpath=0
    for x in `echo $PATH | sed -e "s/:/ /g"`
    do
	[ "$x" = "$usr_prefix/bin" ] && {
	okbinpath=1
	break;
	}
    done

    if [ $oklibpath -eq 0 ]||[ $okbinpath -eq 0 ] ; then echo ""; fi
    if [ $oklibpath -eq 0 ]; then echo "WARNING: our system doesn't support $usr_prefix/lib library path"; fi
    if [ $okbinpath -eq 0 ]; then echo "WARNING: our system doesn't support $usr_prefix/bin executable path"; fi

    if [ $oklibpath -eq 0 ]||[ $okbinpath -eq 0 ] ; then
	echo ""
        echo "Do you want to proceed with the installation?"
	get_agreement
        if [ $? -eq 0 ] ; then
	    echo ""
	    exit 1
        fi
    fi

    #installing the library
    if [ ! -d $libdir ]; then mkdir -p $libdir ; fi
    install -m 755 "$instdir/lib/$avast4libname" "$libdir/$avast4libname" ;
    ( cd lib ; tar cf - `find . -type l` ) | ( cd $libdir ; tar xfU - )

    if [ -h $libdir/libavastengine.so.4 ]; then
	( cd $libdir ; ln -sf $avast4libname libavastengine.so.4 )
    fi
    if [ -f $libdir/libavastengine.so.4.5 ]; then
	( cd $libdir ; ln -sf $avast4libname libavastengine.so.4.5 )
    fi

    if [ ! -f $libdir/$avast4libname ] ; then
	echo ""
	echo "Intallation failed!"
	echo ""
	exit 1
    fi

    #installing executable files
    if [ ! -d $bindir ]; then mkdir -p $bindir ; fi
    install -m 755 "$instdir/bin/$avast4vpsreload" "$bindir/$avast4vpsreload"
    install -m 755 "$instdir/bin/$avast4vpsupdate" "$bindir/$avast4vpsupdate"

    #installing manual pages
    if [ ! -d $mandir/man1 ]; then mkdir -p $mandir/man1 ; fi
    install -m 644 "$instdir/man/man1/$avast4vpsreload.1" "$mandir/man1/$avast4vpsreload.1"
    install -m 644 "$instdir/man/man1/$avast4vpsupdate.1" "$mandir/man1/$avast4vpsupdate.1"
    if [ ! -d $mandir/man5 ]; then mkdir -p $mandir/man5 ; fi
    install -m 644 "$instdir/man/man5/$avast4conffile.5" "$mandir/man5/$avast4conffile.5"

    #installing documentation
    if [ ! -d $docdir/$packagename-$packagevers ]; then mkdir -p $docdir/$packagename-$packagevers ; fi
    install -m 644 "$instdir/AUTHORS" "$docdir/$packagename-$packagevers/AUTHORS"
    install -m 644 "$instdir/ChangeLog" "$docdir/$packagename-$packagevers/ChangeLog"
    install -m 644 "$instdir/INSTALL" "$docdir/$packagename-$packagevers/INSTALL"
    install -m 644 "$instdir/LICENSE" "$docdir/$packagename-$packagevers/LICENSE"
    install -m 644 "$instdir/MANIFEST" "$docdir/$packagename-$packagevers/MANIFEST"
    install -m 644 "$instdir/README" "$docdir/$packagename-$packagevers/README"
    install -m 644 "$instdir/FAQ" "$docdir/$packagename-$packagevers/FAQ"

    #install shared file
    mkdir -p "$datadir" ; chmod 0755 "$datadir"
    install -m 644 "$instdir/var/$avast4vpsfile" "$datadir/$avast4vpsfile"
    mkdir -p "$tempdir" ; chmod 1777 "$tempdir"
    mkdir -p "$logdir" ; chmod 0755 "$logdir"
    mkdir -p "$moveddir" ; chmod 1777 "$moveddir"
    mkdir -p "$licdir" ; chmod 0755 "$licdir"
    #install -m 644 "$instdir/var/$avast4licfile" "$datadir/$avast4licfile"

    #installing etc files
    if [ ! -d $sysdir ]; then mkdir -p $sysdir ; fi
    if [ -f $sysdir/$avast4conffile ]; then mv "$sysdir/$avast4conffile" "$sysdir/$avast4conffile.old" ; fi
    install -m 644 "$instdir/etc/$avast4conffile" "$sysdir/$avast4conffile"
    if [ -f $sysdir/$avast4vpsupdateconf ]; then mv "$sysdir/$avast4vpsupdateconf" "$sysdir/$avast4vpsupdateconf.old" ; fi
    install -m 644 "$instdir/etc/$avast4vpsupdateconf" "$sysdir/$avast4vpsupdateconf"

sleep 1
echo " "
echo "NOT INSTALLING VPS updater cron scripts as this is handled by surgemail"
echo "   (to update manually run 'av_avast -update')"

#    #set crontab item for the avastvpsupdate.pl script
#    crontab -l 2>/dev/null | grep -v "# DO NOT EDIT THIS FILE -" | grep -v "# (${CRONTABTMP}" | grep -v "# (Cron version --" > ${CRONTABTMP}
#    echo "0 */6 * * * $bindir/$avast4vpsupdate" >> ${CRONTABTMP}
#    crontab ${CRONTABTMP}
#    rm -f ${CRONTABTMP}

#    #update cron daemon
#    pid=`ps a | grep crond | awk '{print $1}'`
#    if [ "${pid}" = "0" ]; then
#	kill -HUP ${pid}
#    fi

    sleep 1
    echo ""
    echo "In which directory is Surgemail installed?"
    get_installagreement $surgemaildir

    echo ""
    echo "Installing av_avast in the surgemail drectory ($surgemaildir)"
    echo ""

    cp -f "$instdir/av_avast" "$surgemaildir"
    mkdir -p "$surgemaildir/avast"

    chown -R mail.mail "$surgemaildir/avast"
    chown -R mail.mail "$datadir"
    chown -R mail.mail "$tempdir"
    chown -R mail.mail "$logdir"
    chown -R mail.mail "$moveddir"

    # Just make sure upgrade installs are ok
#    chown -R mail.mail "$avast4tmpdir/400.vps*" 2>/dev/nul
#    chown -R mail.mail "$avast4tmpdir/400vps.md5*"  2>/dev/nul
    rm -f /var/lib/avast4/400vps.md5  2>/dev/nul

    echo ""
    echo "The $avast4libname library installation complete."
    echo ""
#    echo "***NOTE***: this script has set the cron daemon to check for the new VPS"
#    echo "file periodicaly after six hours. You can change this period by using"
#    echo "'crontab -e' command. The configuration for updating VPS is available"
#    echo "in $sysdir/$avast4vpsupdateconf file."
#    echo "Make sure Digest::MD5, File::Spec, LWP::UserAgent and URI Perl modules"
#    echo "are installed before running '$bindir/$avast4vpsupdate' script."
#    echo ""
#    echo "***NOTE***: the installation package does not contain a license file."
#    echo "The program will not work without a license file. A valid license file"
#    echo "(with either a DEMO or a RELEASE license) _must_ be supplied."
#    echo "To request a DEMO license, please visit the following web page:"
#    echo "http://www.avast.com/i_kat_340.php?lang=ENG"
#    echo ""

    echo "To test your Surgemail Linux Avast install:"
    echo "	run './av_avast -test' in the /usr/local/surgemail directory"
    echo ""
    echo "To use with surgemail use the following settings"
    echo "	g_virus_filter cmd=\"av_avast\" type=\"\" "
    echo "	g_virus_avast \"true\""
    echo "	g_virus_avast_hour \"0,6,12,18\" "
    echo ""
    echo "For further help see: http://netwinsite.com/surgemail/help/avast.htm"

}

#install user configuration
func_makeuserconf ()
{
    if [ -z $1 ]; then
        userhomedir=`(cd ~;pwd)`;
    else
	userhomedir=$1;
    fi

    echo ""
    echo ""
    echo "Copyright(C) 2003-2005 ALWIL Software.  All rights reserved."
    echo ""
    echo "Please install as root, if you know what you are doing edit this install"
    echo "script to install as a particular user."
    exit 0
    
    
    echo ""
    echo "the avast! engine for $platform configuration file for '`whoami`' user"
    echo "will be installed in $userhomedir directory."
    echo ""
    echo "To install '$userhomedir/.$avast4conffile' configuration file now, press ENTER."
    echo ""
    echo "To cancel the installation at any time, press Control-C."
    echo ""
    read cont < /dev/tty

    tempdir_home="$userhomedir/.avastengine/tmp"
    datadir_home="$userhomedir/.avastengine"
    moveddir_home="$userhomedir/.avastengine/moved"
    logdir_home="$userhomedir/.avastengine/log"
    licdir_home="$userhomedir/.avastengine"

    echo ""
    echo "The following directories will be used by the shared library:"
    echo "    data dir:    $datadir_home"
    echo "    temp dir:    $tempdir_home"
    echo "    log dir:     $logdir_home"
    echo "    moved dir:   $moveddir_home"
    echo "    license dir: $licdir_home"
    echo ""

    mkdir -p "$userhomedir/.avastengine" ; chmod 0700 "$userhomedir/.avastengine"

    mkdir -p "$datadir_home" ; chmod 0700 "$datadir_home"
    install -m 644 "$instdir/var/$avast4vpsfile" "$datadir_home/$avast4vpsfile"
    mkdir -p "$tempdir_home" ; chmod 0700 $tempdir_home
    mkdir -p "$logdir_home" ; chmod 0700 $logdir_home
    mkdir -p "$moveddir_home" ; chmod 0700 $moveddir_home
    mkdir -p "$licdir_home" ; chmod 0700 $licdir_home
    #install -m 644 "$instdir/var/$avast4licfile" "$datadir/$avast4licfile"

    #installing etc files
    if [ -f $userhomedir/.$avast4conffile ]; then mv "$userhomedir/.$avast4conffile" "$userhomedir/.$avast4conffile.old" ; fi
    #update configuration paths
    cat $instdir/etc/$avast4conffile | while read line
    do
	case `echo $line | sed 's/=.*//'` in
        Avast4DataDir ) echo "Avast4DataDir=$datadir_home" >> $userhomedir/.$avast4conffile ;;
	Avast4TempDir ) echo "Avast4TempDir=$tempdir_home" >> $userhomedir/.$avast4conffile ;;
        Avast4MovedDir ) echo "Avast4MovedDir=$moveddir_home" >> $userhomedir/.$avast4conffile ;;
	Avast4LogDir ) echo "Avast4LogDir=$logdir_home" >> $userhomedir/.$avast4conffile ;;
        Avast4LicenseDir ) echo "Avast4LicenseDir=$licdir_home" >> $userhomedir/.$avast4conffile ;;
	Avast4LicenseFile ) echo "Avast4LicenseFile=$licdir_home/$avast4licfile" >> $userhomedir/.$avast4conffile ;;
        * ) echo "$line" >> $userhomedir/.$avast4conffile ;;
	esac
    done
    chmod 644 $userhomedir/.$avast4conffile

    echo ""
    echo "The configuration file installed!"
    echo ""
    echo "To keep your VPS file fresh, please, install '~/.$avast4vpsupdateconf'"
    echo "file (by running './mkinstall.sh -v' command) and then setup the cron"
    echo "daemon to periodically check for a new version."
    echo ""
}

func_makeuserupdateconf ()
{
    if [ -z $1 ]; then
        userhomedir=`(cd ~;pwd)`;
    else
	userhomedir=$1;
    fi

    echo ""
    echo ""
    echo "Copyright(C) 2003-2005 ALWIL Software.  All rights reserved."
    echo ""
    echo "the avast! VPS updating configuration file for '`whoami`' user"
    echo "will be installed in $userhomedir directory."
    echo ""
    echo "To install '$userhomedir/.$avast4vpsupdateconf' configuration file now, press ENTER."
    echo ""
    echo "To cancel the installation at any time, press Control-C."
    echo ""
    read cont < /dev/tty

    if [ -f $userhomedir/.$avast4vpsupdateconf ]; then mv "$userhomedir/.$avast4vpsupdateconf" "$userhomedir/.$avast4vpsupdateconf.old" ; fi
    cat $instdir/etc/$avast4vpsupdateconf > $userhomedir/.$avast4vpsupdateconf
    chmod 644 $userhomedir/.$avast4vpsupdateconf

    echo ""
    echo "The configuration file installed!"
    echo ""
    echo "To keep your VPS file up to date, please, run 'crontab -e' to edit"
    echo "crontab table to set 'avastvpsupdate.pl' script to be running by the"
    echo "cron daemon in user defined period. Please, consult crontab manual page"
    echo "to know, how to do it (man -S 1 crontab)."
    echo "To check for the VPS file every sixth hour, please insert into crontab:"
    echo "0 */6 * * * $bindir/$avast4vpsupdate"
    echo ""
}

func_uninstall ()
{
    echo ""
    echo ""
    echo "Copyright(C) 2003-2005 ALWIL Software.  All rights reserved."
    echo ""
    echo "To uninstall '$avast4libname' library now, press ENTER."
    echo ""
    echo "To cancel the installation at any time, press Control-C."
    echo ""
    read cont < /dev/tty

    #check for previous library intallation
    func_docheck
    echo ""
    previnstall=0;
    if [ ! -z $check_lib_librarydir ] ; then echo "found installed $check_lib_librarydir/$avast4libname file" ; previnstall=1 ; fi
    if [ ! -z $check_bin_vpsreloaddir ] ; then echo "found installed $check_bin_vpsreloaddir/$avast4vpsreload file" ; previnstall=1 ;fi
    if [ ! -z $check_bin_vpsupdatedir ] ; then echo "found installed $check_bin_vpsupdatedir/$avast4vpsupdate file" ; previnstall=1 ;fi
    if [ ! -z $check_man1_vpsreloaddir ] ; then echo "found installed $check_man1_vpsreloaddir/$avast4vpsreload.1 file" ; previnstall=1 ;fi
    if [ ! -z $check_man1_vpsupdatedir ] ; then echo "found installed $check_man1_vpsupdatedir/$avast4vpsupdate.1 file" ; previnstall=1 ;fi
    if [ ! -z $check_man5_engineconfdir ] ; then echo "found installed $check_man5_engineconfdir/$avast4conffile.5 file" ; previnstall=1 ;fi
    if [ ! -z $check_doc_dir ] ; then echo "found installed $check_doc_dir directory" ; previnstall=1 ;fi

    if [ $previnstall -eq 1 ] ; then
	echo ""
        echo "Do you want to uninstall these files?"
	get_agreement
        if [ $? -eq 0 ] ; then
    	    exit 1
	else
	    if [ ! -z $check_lib_librarydir ] ; then
		rm -f $check_lib_librarydir/$avast4libname ;
		rm -f $check_lib_librarydir/$avast4liblink ;
		rm -f $check_lib_librarydir/$avast4liblink2 ;
	    fi
	    if [ ! -z $check_bin_vpsreloaddir ] ; then rm -f $check_bin_vpsreloaddir/$avast4vpsreload ; fi
	    if [ ! -z $check_bin_vpsupdatedir ] ; then rm -f $check_bin_vpsupdatedir/$avast4vpsupdate ; fi
	    if [ ! -z $check_man1_vpsreloaddir ] ; then rm -f $check_man1_vpsreloaddir/$avast4vpsreload.1 ; fi
	    if [ ! -z $check_man1_vpsupdatedir ] ; then rm -f $check_man1_vpsupdatedir/$avast4vpsupdate.1 ; fi
	    if [ ! -z $check_man5_engineconfdir ] ; then rm -f $check_man5_engineconfdir/$avast4conffile.5 ; fi
	    if [ ! -z $check_doc_dir ] ; then rm -f $check_doc_dir/* ; rmdir $check_doc_dir 2>/dev/null ; fi

	    #400.vps file
	    if [ ! -z $check_var_avast4datadir ] ; then rm -f $check_var_avast4datadir/$avast4vpsfile ; fi

	    #uninstall crontab item for the avastvpsupdate.pl script
	    crontab -l 2>/dev/null | grep "* $check_bin_vpsupdatedir/$avast4vpsupdate" >/dev/null
	    if [ $? -eq 0 ]; then
		rm -f ${CRONTABTMP}
		crontab -l 2>/dev/null | grep -v "# DO NOT EDIT THIS FILE -" | grep -v "# (${CRONTABTMP}" | grep -v "# (Cron version --" | while read line
		do
		    echo "$line" | grep "* $check_bin_vpsupdatedir/$avast4vpsupdate" >/dev/null
		    if [ $? -ne 0 ]; then
			echo "$line" >> ${CRONTABTMP}
		    fi
		done
		if [ -f ${CRONTABTMP} ]; then
		    crontab ${CRONTABTMP}
		    rm -f ${CRONTABTMP}
		else
		    crontab -d > /dev/null 2>&1
		    if [ $? -ne 0 ]; then
			echo "y" | crontab -r > /dev/null 2>&1
		    fi
		fi

		# update cron daemon
		pid=`ps a | grep crond | awk '{print $1}'`
		if [ "${pid}" = "0" ]; then
		    kill -HUP ${pid}
		fi
	    fi

	    echo ""
	    echo "Uninstallation complete!"
	    echo ""
	fi
    else
	echo ""
	echo "Could not find previously installed files !!!"
	echo ""
	exit 1
    fi
}


while test "$#" -gt 0
do
  arg="$1"
  shift

  case $arg in
      -*=*) optarg=`echo "$arg" | sed -e 's/[-_a-zA-Z0-9]*=//'` ;;
      *) optarg= ;;
  esac

  case "$arg" in
      --prefix=* | -p=* )
	  if [ $optarg == "/usr/local" ]; then sys_prefix=$optarg ; fi
	  usr_prefix=$optarg;

	  sysdir="$sys_prefix/etc"
	  bindir="$usr_prefix/bin"
	  libdir="$usr_prefix/lib"
	  docdir="$usr_prefix/share/doc"
	  mandir="$usr_prefix/share/man"
	  if [ "$usr_prefix" = "/usr/local" ] && [ ! `uname -s` = "Linux" ]; then
	      mandir="$usr_prefix/man";
          fi

	  #tempdir="$var_prefix/tmp/avast4"
	  #datadir="$var_prefix/lib/avast4"
	  #moveddir="$var_prefix/lib/avast4/moved"
	  #logdir="$var_prefix/lib/avast4/log"
	  #licdir="$var_prefix/lib/avast4"

	  ;;
      --uninstall | -u )
	  check_user
	  func_uninstall; exit 0;;
      --mkconf | -c )
	  func_makeuserconf; exit 0 ;;
      --mkupdateconf | -v )
	  func_makeuserupdateconf; exit 0 ;;
      --help | -h )
	  func_help; exit 0 ;;
      --version | -V )
	  func_version; exit 0 ;;
  esac
done
#func_usage 1>&2
check_user
func_install

exit 0
